picuplib
=========

Small python library for uploading pictures to [picflash.org](https://picflash.org)

Requirements:
* python 2.6 or better.
    * Python 3 is supported too.
* requests

Documentation can be found on [ReadTheDocs](http://picuplib.readthedocs.org/en/latest/)

Installation
============
1. Download and unpack the tarball or clone the repo
2. type ``python setup.py install``
